@@ -6,9 +6,7 @@ use warnings;
 use Text::Aligner qw( align);
 
 BEGIN {
-    use Exporter ();
-    our $VERSION = ('$Revision: 1.107 $' =~ /(\d+.\d+)/)[ 0];
-
+    our $VERSION = 1.116;
 }
 
 use overload
@@ -208,7 +206,7 @@ sub add {
     my $tb = shift;
     $tb->_entitle( ( '') x @_) unless $tb->n_cols;
 
-    $tb->_add( @$_) for _transpose( map [ defined() ? split( $/ ) : '' ], @_);
+    $tb->_add( @$_) for _transpose( map [ defined() ? split( /\n/ ) : '' ], @_);
     $tb->_clear_cache;
 }   
 
@@ -383,7 +381,7 @@ sub _transpose_n ($@) {
 # like _transpose_n, but find the number to transpose from max of given
 sub _transpose {
     my $m;
-    _to_max( $m, scalar @$_) for @_;
+    _to_max( $m, scalar @$_) for @_, []; # make sure $m is defined
     _transpose_n( $m, @_);
 }
 
@@ -551,6 +549,9 @@ for all table columns.  A bulk loader for many lines at once is also
 available.  You can clear the data from the table for re-use (though
 you will more likely just create another table).
 
+Data can contain colorizing escape sequences (as provided by
+C<Term::AnsiColor>) without upsetting the alignment.
+
 =head2 Table Output
 
 The output area of a table is divided in the title and the body.
@@ -835,8 +836,7 @@ returns the number of title lines in a table.
 
     $tb->body_height
 
-returns the number of lines in the table body, which is the number
-of data lines that were entered via L<"add()"> or L<"load()">.
+returns the number of lines in the table body.
 
 =item colrange()
 
@@ -844,7 +844,7 @@ of data lines that were entered via L<"add()"> or L<"load()">.
 
 returns the start position and width of the $i-th column (counting from 0)
 of the table.  If $i is negative, counts from the end of the table.  If $i
-is larger than the greatesit column index, an imaginary column of width 0
+is larger than the greatest column index, an imaginary column of width 0
 is assumed right of the table.
 
 =back
